
Example Blank Slate
===================

Sets up a python, python3, pypy5, nodejs and golang -project

```
slate install bootstrap
slate install example
slate run
```
Browse to http://localhost:9000 and other haproxy-defined routes.

